@@ -971,6 +971,12 @@ class SphinxRenderer:
             display_obj_type = 'interface' if kind == 'interface' else None
             nodes = self.handle_declaration(nodeDef, declaration, content_callback=content,
                                             display_obj_type=display_obj_type)
+            if 'members-only' in self.context.directive_args[2]:
+                assert len(nodes) >= 2
+                assert isinstance(nodes[1], addnodes.desc)
+                assert len(nodes[1]) >= 2
+                assert isinstance(nodes[1][1], addnodes.desc_content)
+                return nodes[1][1].children
         return nodes
 
     def visit_namespace(self, node) -> List[Node]:
@@ -1087,25 +1093,34 @@ class SphinxRenderer:
 
     def visit_file(self, node) -> List[Node]:
         def render_signature(file_data, doxygen_target, name, kind):
-            # Build targets for linking
-            targets = []
-            targets.extend(doxygen_target)
+            self.context = cast(RenderContext, self.context)
+            options = self.context.directive_args[2]
 
-            title_signode = addnodes.desc_signature()
-            title_signode.extend(targets)
+            if "content-only" in options:
+                rst_node = nodes.container()
+            else:
+                rst_node = addnodes.desc()
 
-            # Set up the title
-            title_signode.append(nodes.emphasis(text=kind))
-            title_signode.append(nodes.Text(" "))
-            title_signode.append(addnodes.desc_name(text=name))
+                # Build targets for linking
+                targets = []
+                targets.extend(doxygen_target)
 
-            contentnode = addnodes.desc_content()
+                title_signode = addnodes.desc_signature()
+                title_signode.extend(targets)
+
+                # Set up the title
+                title_signode.append(nodes.emphasis(text=kind))
+                title_signode.append(nodes.Text(" "))
+                title_signode.append(addnodes.desc_name(text=name))
+
+                rst_node.append(title_signode)
 
-            rst_node = addnodes.desc()
             rst_node.document = self.state.document
             rst_node['objtype'] = kind
-            rst_node.append(title_signode)
+
+            contentnode = addnodes.desc_content()
             rst_node.append(contentnode)
+
             return [rst_node], contentnode
         return self.visit_compound(node, render_signature=render_signature)
 
@@ -1160,6 +1175,9 @@ class SphinxRenderer:
         section_order = None
         if 'sections' in options:
             section_order = {sec: i for i, sec in enumerate(options['sections'].split(' '))}
+        membergroup_order = None
+        if 'membergroups' in options:
+            membergroup_order = {sec: i for i, sec in enumerate(options['membergroups'].split(' '))}
         nodemap = {}  # type: Dict[int, List[Node]]
 
         def addnode(kind, lam):
@@ -1168,23 +1186,25 @@ class SphinxRenderer:
             elif kind in section_order:
                 nodemap.setdefault(section_order[kind], []).extend(lam())
 
-        addnode('briefdescription', lambda: self.render_optional(node.briefdescription))
-        addnode('detaileddescription', lambda: self.render_optional(node.detaileddescription))
+        if 'members-only' not in options:
+            addnode('briefdescription', lambda: self.render_optional(node.briefdescription))
+            addnode('detaileddescription', lambda: self.render_optional(node.detaileddescription))
 
-        def render_derivedcompoundref(node):
-            if node is None:
-                return []
-            output = self.render_iterable(node)
-            if not output:
-                return []
-            return [nodes.paragraph(
-                '',
-                '',
-                nodes.Text('Subclassed by '),
-                *intersperse(output, nodes.Text(', '))
-            )]
+            def render_derivedcompoundref(node):
+                if node is None:
+                    return []
+                output = self.render_iterable(node)
+                if not output:
+                    return []
+                return [nodes.paragraph(
+                    '',
+                    '',
+                    nodes.Text('Subclassed by '),
+                    *intersperse(output, nodes.Text(', '))
+                )]
 
-        addnode('derivedcompoundref', lambda: render_derivedcompoundref(node.derivedcompoundref))
+            addnode('derivedcompoundref',
+                    lambda: render_derivedcompoundref(node.derivedcompoundref))
 
         section_nodelists = {}  # type: Dict[str, List[Node]]
 
@@ -1193,6 +1213,9 @@ class SphinxRenderer:
             kind = sectiondef.kind
             if section_order is not None and kind not in section_order:
                 continue
+            header = sectiondef.header
+            if membergroup_order is not None and header not in membergroup_order:
+                continue
             child_nodes = self.render(sectiondef)
             if not child_nodes:
                 # Skip empty section
@@ -1229,6 +1252,8 @@ class SphinxRenderer:
     section_titles = dict(sections)
 
     def visit_sectiondef(self, node) -> List[Node]:
+        self.context = cast(RenderContext, self.context)
+        options = self.context.directive_args[2]
         node_list = []
         node_list.extend(self.render_optional(node.description))
 
@@ -1236,6 +1261,9 @@ class SphinxRenderer:
         node_list.extend(self.render_iterable(node.memberdef))
 
         if node_list:
+            if 'members-only' in options:
+                return node_list
+
             text = self.section_titles[node.kind]
             # Override default name for user-defined sections. Use "Unnamed
             # Group" if the user didn't name the section
@@ -1249,7 +1277,10 @@ class SphinxRenderer:
 
             # Use rubric for the title because, unlike the docutils element "section",
             # it doesn't interfere with the document structure.
-            rubric = nodes.rubric(text=text, classes=['breathe-sectiondef-title'])
+            idtext = text.replace(' ', '-').lower()
+            rubric = nodes.rubric(text=text,
+                                  classes=['breathe-sectiondef-title'],
+                                  ids=['breathe-section-title-'+idtext])
             res = [rubric]  # type: List[Node]
             return res + node_list
         return []
@@ -1290,22 +1321,27 @@ class SphinxRenderer:
         neighbouring instances of these things tend to each be in a separate neighbouring para tag.
         """
 
-        nodelist = self.render_iterable(node.content)
-        nodelist.extend(self.render_iterable(node.images))
+        nodelist = []
 
-        if self.app.config.breathe_order_parameters_first:  # type: ignore
-            # Order parameters before simplesects, which mainly are return/warnings/remarks
-            definition_nodes = self.render_iterable(node.parameterlist)
-            definition_nodes.extend(self.render_iterable(node.simplesects))
+        if self.context and self.context.directive_args[0] == "doxygenpage":
+            nodelist.extend(self.render_iterable(node.ordered_children))
         else:
-            # Returns, user par's, etc
-            definition_nodes = self.render_iterable(node.simplesects)
-            # Parameters/Exceptions
-            definition_nodes.extend(self.render_iterable(node.parameterlist))
+            nodelist.extend(self.render_iterable(node.content))
+            nodelist.extend(self.render_iterable(node.images))
 
-        if definition_nodes:
-            definition_list = nodes.definition_list("", *definition_nodes)
-            nodelist.append(definition_list)
+            if self.app.config.breathe_order_parameters_first:  # type: ignore
+                # Order parameters before simplesects, which mainly are return/warnings/remarks
+                definition_nodes = self.render_iterable(node.parameterlist)
+                definition_nodes.extend(self.render_iterable(node.simplesects))
+            else:
+                # Returns, user par's, etc
+                definition_nodes = self.render_iterable(node.simplesects)
+                # Parameters/Exceptions
+                definition_nodes.extend(self.render_iterable(node.parameterlist))
+
+            if definition_nodes:
+                definition_list = nodes.definition_list("", *definition_nodes)
+                nodelist.append(definition_list)
 
         return [nodes.paragraph("", "", *nodelist)]
 
@@ -1354,8 +1390,8 @@ class SphinxRenderer:
         '''
         section = nodes.section()
         section['ids'].append(self.get_refid(node.id))
-        section += self.create_doxygen_target(node)
         section += nodes.title(node.title, node.title)
+        section += self.create_doxygen_target(node)
         section += self.render_iterable(node.content_)
         return [section]
 
@@ -1630,6 +1666,10 @@ class SphinxRenderer:
         col += self.render_iterable(node.para)
         if node.thead == 'yes':
             col['heading'] = True
+        if node.rowspan:
+            col['morerows'] = int(node.rowspan) - 1
+        if node.colspan:
+            col['morecols'] = int(node.colspan) - 1
         return [col]
 
     def visit_docrow(self, node) -> List[Node]:
@@ -1652,7 +1692,26 @@ class SphinxRenderer:
             colspec.attributes['colwidth'] = 'auto'
             tgroup += colspec
         table += tgroup
-        tgroup += self.render_iterable(node.row)
+        rows = self.render_iterable(node.row)
+
+        # this code depends on visit_docrow(), and expects the same elements used to
+        # "envelop" rows there, namely thead and tbody (eg it will need to be updated
+        # if Doxygen one day adds support for tfoot)
+
+        tags = {row.starttag(): [] for row in rows}  # type: Dict[str, List]
+        for row in rows:
+            tags[row.starttag()].append(row.next_node())
+
+        def merge_row_types(root, elem, elems):
+            for node in elems:
+                elem += node
+            root += elem
+
+        for klass in [nodes.thead, nodes.tbody]:
+            obj = klass()
+            if obj.starttag() in tags:
+                merge_row_types(tgroup, obj, tags[obj.starttag()])
+
         return [table]
 
     def visit_mixedcontainer(self, node) -> List[Node]:
@@ -1844,9 +1903,19 @@ class SphinxRenderer:
             typename = ''.join(n.astext() for n in self.render(node.get_type()))
             if dom == 'c' and '::' in typename:
                 typename = typename.replace('::', '.')
+            elif dom == 'cs':
+                typename = typename.replace(' ', '')
             elements.append(typename)
             elements.append(name)
             elements.append(node.get_argsstring())
+            if dom == 'cs':
+                if node.get_gettable() or node.get_settable():
+                    elements.append('{')
+                    if node.get_gettable():
+                        elements.append('get;')
+                    if node.get_settable():
+                        elements.append('set;')
+                    elements.append('}')
             elements.append(self.make_initializer(node))
             declaration = ' '.join(elements)
         if not dom or dom in ('c', 'cpp', 'py', 'cs'):
